# dgus-control

**dgus-control** is a stateful UI automation toolkit built for controlling DGUS-based GUIs on Windows.  

Features:
- Operate a dgus instance (usually a clone)
- Screen creation and navigation
- Allocating memory
- Widget creation and widget attribute writing

## Installation

```bash
pip install dgus-control
```

## Usage
```py
import dgus_control
print(dgus_control.__version__)  # will be updated after more implementation is done
```

## Disclaimer
This project is not affiliated with or endorsed by DWIN Technology or DGUS. <br>
It is an independent toolkit to automate UI interactions with DGUS-based interfaces.